GENRES={"GENRE_ACTION":"8",
"GENRE_ADULT":"280",
"GENRE_ADVENTURE":"13",
"GENRE_COMEDY":"17",
"GENRE_DRAMA":"9",
"GENRE_ECCHI":"292",
"GENRE_FANTASY":"5",
"GENRE_GENDER_BENDER":"168",
"GENRE_HAREM":"3",
"GENRE_HISTORICAL":"330",
"GENRE_HORROR":"343",
"GENRE_JOSEI":"324",
"GENRE_MARTIAL_ARTS":"14",
"GENRE_MATURE":"4",
"GENRE_MECHA":"10",
"GENRE_MYSTERY":"245",
"GENRE_PSYCHOLOGICAL":"486",
"GENRE_ROMANCE":"15",
"GENRE_SCHOOL_LIFE":"6",
"GENRE_SCIFI":"11",
"GENRE_SEINEN":"18",
"GENRE_SHOUJO":"157",
"GENRE_SHOUJO_AI":"851",
"GENRE_SHOUNEN":"12",
"GENRE_SHOUNEN_AI":"1692",
"GENRE_SLICE_OF_LIFE":"7",
"GENRE_SMUT":"281",
"GENRE_SPORTS":"1357",
"GENRE_SUPERNATURAL":"16",
"GENRE_TRAGEDY":"132",
"GENRE_WUXIA":"479",
"GENRE_XIANXIA":"480",
"GENRE_XUANHUAN":"3954",
"GENRE_YAOI":"560",
"GENRE_YURI":"922",
}