TAGS={"TAG_ABANDONED_CHILDREN":"16185",
"TAG_ABILITY_STEAL":"4859",
"TAG_ABSENT_PARENTS":"1248",
"TAG_ABUSIVE_CHARACTERS":"11325",
"TAG_ACADEMY":"4885",
"TAG_ACCELERATED_GROWTH":"475",
"TAG_ACTING":"13403",
"TAG_ADAPTED_FROM_MANGA":"4976",
"TAG_ADAPTED_FROM_MANHUA":"6280",
"TAG_ADAPTED_TO_ANIME":"269",
"TAG_ADAPTED_TO_DRAMA":"2999",
"TAG_ADAPTED_TO_DRAMA_CD":"928",
"TAG_ADAPTED_TO_GAME":"891",
"TAG_ADAPTED_TO_MANGA":"270",
"TAG_ADAPTED_TO_MANHUA":"182",
"TAG_ADAPTED_TO_MANHWA":"2721",
"TAG_ADAPTED_TO_MOVIE":"1133",
"TAG_ADAPTED_TO_VISUAL_NOVEL":"1334",
"TAG_ADOPTED_CHILDREN":"858",
"TAG_ADOPTED_PROTAGONIST":"603",
"TAG_ADULTERY":"4974",
"TAG_ADVENTURERS":"3108",
"TAG_AFFAIR":"3802",
"TAG_AGE_PROGRESSION":"357",
"TAG_AGE_REGRESSION":"216",
"TAG_AGGRESSIVE_CHARACTERS":"13720",
"TAG_ALCHEMY":"234",
"TAG_ALIENS":"621",
"TAG_ALLGIRLS_SCHOOL":"598",
"TAG_ALTERNATE_WORLD":"7909",
"TAG_AMNESIA":"625",
"TAG_AMUSEMENT_PARK":"774",
"TAG_ANAL":"4594",
"TAG_ANCIENT_CHINA":"476",
"TAG_ANCIENT_TIMES":"2662",
"TAG_ANDROGYNOUS_CHARACTERS":"13263",
"TAG_ANDROIDS":"892",
"TAG_ANGELS":"1327",
"TAG_ANIMAL_CHARACTERISTICS":"255",
"TAG_ANIMAL_REARING":"7323",
"TAG_ANTIMAGIC":"724",
"TAG_ANTISOCIAL_PROTAGONIST":"1732",
"TAG_ANTIHERO_PROTAGONIST":"4297",
"TAG_ANTIQUE_SHOP":"203",
"TAG_APARTMENT_LIFE":"513",
"TAG_APATHETIC_PROTAGONIST":"12913",
"TAG_APOCALYPSE":"217",
"TAG_APPEARANCE_CHANGES":"721",
"TAG_APPEARANCE_DIFFERENT_FROM_ACTUAL_AGE":"430",
"TAG_ARCHERY":"697",
"TAG_ARISTOCRACY":"6442",
"TAG_ARMS_DEALERS":"9591",
"TAG_ARMY":"306",
"TAG_ARMY_BUILDING":"9522",
"TAG_ARRANGED_MARRIAGE":"2676",
"TAG_ARROGANT_CHARACTERS":"13427",
"TAG_ARTIFACT_CRAFTING":"9851",
"TAG_ARTIFACTS":"4699",
"TAG_ARTIFICIAL_INTELLIGENCE":"141",
"TAG_ARTISTS":"271",
"TAG_ASSASSINS":"81",
"TAG_ASTROLOGERS":"8965",
"TAG_AUTISM":"9776",
"TAG_AUTOMATONS":"11491",
"TAG_AVERAGELOOKING_PROTAGONIST":"12917",
"TAG_AWARDWINNING_WORK":"1134",
"TAG_AWKWARD_PROTAGONIST":"13016",
"TAG_BANDS":"4975",
"TAG_BASED_ON_A_MOVIE":"1346",
"TAG_BASED_ON_A_SONG":"1632",
"TAG_BASED_ON_A_TV_SHOW":"6572",
"TAG_BASED_ON_A_VIDEO_GAME":"1442",
"TAG_BASED_ON_A_VISUAL_NOVEL":"1447",
"TAG_BASED_ON_AN_ANIME":"1230",
"TAG_BATTLE_ACADEMY":"825",
"TAG_BATTLE_COMPETITION":"6308",
"TAG_BDSM":"10668",
"TAG_BEAST_COMPANIONS":"5363",
"TAG_BEASTKIN":"5406",
"TAG_BEASTS":"116",
"TAG_BEAUTIFUL_FEMALE_LEAD":"111",
"TAG_BESTIALITY":"15625",
"TAG_BETRAYAL":"256",
"TAG_BICKERING_COUPLE":"2573",
"TAG_BIOCHIP":"13371",
"TAG_BISEXUAL_PROTAGONIST":"6359",
"TAG_BLACK_BELLY":"2943",
"TAG_BLACKMAIL":"916",
"TAG_BLACKSMITH":"2734",
"TAG_BLIND_DATES":"9280",
"TAG_BLIND_PROTAGONIST":"2347",
"TAG_BLOOD_MANIPULATION":"9492",
"TAG_BLOODLINES":"5824",
"TAG_BODY_SWAP":"2642",
"TAG_BODY_TEMPERING":"9907",
"TAG_BODYDOUBLE":"568",
"TAG_BODYGUARDS":"224",
"TAG_BOOKS":"1288",
"TAG_BOOKWORM":"13805",
"TAG_BOSSSUBORDINATE_RELATIONSHIP":"325",
"TAG_BRAINWASHING":"1710",
"TAG_BREAST_FETISH":"5607",
"TAG_BROKEN_ENGAGEMENT":"9410",
"TAG_BROTHER_COMPLEX":"604",
"TAG_BROTHERHOOD":"8185",
"TAG_BUDDHISM":"3825",
"TAG_BULLYING":"123",
"TAG_BUSINESS_MANAGEMENT":"782",
"TAG_BUSINESSMEN":"11786",
"TAG_BUTLERS":"1597",
"TAG_CALM_PROTAGONIST":"12910",
"TAG_CANNIBALISM":"4248",
"TAG_CARD_GAMES":"2774",
"TAG_CAREFREE_PROTAGONIST":"11345",
"TAG_CARING_PROTAGONIST":"12951",
"TAG_CAUTIOUS_PROTAGONIST":"12914",
"TAG_CELEBRITIES":"2304",
"TAG_CHARACTER_GROWTH":"257",
"TAG_CHARISMATIC_PROTAGONIST":"14493",
"TAG_CHARMING_PROTAGONIST":"14985",
"TAG_CHAT_ROOMS":"1942",
"TAG_CHEATS":"5708",
"TAG_CHEFS":"1832",
"TAG_CHILD_ABUSE":"1368",
"TAG_CHILD_PROTAGONIST":"3470",
"TAG_CHILDCARE":"1391",
"TAG_CHILDHOOD_FRIENDS":"85",
"TAG_CHILDHOOD_LOVE":"917",
"TAG_CHILDHOOD_PROMISE":"691",
"TAG_CHILDISH_PROTAGONIST":"14986",
"TAG_CHUUNIBYOU":"169",
"TAG_CLAN_BUILDING":"4423",
"TAG_CLASSIC":"7777",
"TAG_CLEVER_PROTAGONIST":"14587",
"TAG_CLINGY_LOVER":"2356",
"TAG_CLONES":"2274",
"TAG_CLUBS":"611",
"TAG_CLUMSY_LOVE_INTERESTS":"14989",
"TAG_COWORKERS":"7951",
"TAG_COHABITATION":"710",
"TAG_COLD_LOVE_INTERESTS":"14606",
"TAG_COLD_PROTAGONIST":"14605",
"TAG_COLLECTION_OF_SHORT_STORIES":"8656",
"TAG_COLLEGEUNIVERSITY":"7776",
"TAG_COMA":"1675",
"TAG_COMEDIC_UNDERTONE":"124",
"TAG_COMING_OF_AGE":"282",
"TAG_COMPLEX_FAMILY_RELATIONSHIPS":"4822",
"TAG_CONDITIONAL_POWER":"7117",
"TAG_CONFIDENT_PROTAGONIST":"14673",
"TAG_CONFINEMENT":"1404",
"TAG_CONFLICTING_LOYALTIES":"3241",
"TAG_CONTRACTS":"859",
"TAG_COOKING":"2506",
"TAG_CORRUPTION":"352",
"TAG_COSMIC_WARS":"9926",
"TAG_COSPLAY":"7844",
"TAG_COUPLE_GROWTH":"592",
"TAG_COURT_OFFICIAL":"5792",
"TAG_COUSINS":"836",
"TAG_COWARDLY_PROTAGONIST":"3752",
"TAG_CRAFTING":"5944",
"TAG_CRIME":"2969",
"TAG_CRIMINALS":"443",
"TAG_CROSSDRESSING":"769",
"TAG_CROSSOVER":"1795",
"TAG_CRUEL_CHARACTERS":"12956",
"TAG_CRYOSTASIS":"19556",
"TAG_CULTIVATION":"117",
"TAG_CUNNILINGUS":"4596",
"TAG_CUNNING_PROTAGONIST":"14593",
"TAG_CURIOUS_PROTAGONIST":"14990",
"TAG_CURSES":"579",
"TAG_CUTE_CHILDREN":"16457",
"TAG_CUTE_PROTAGONIST":"14987",
"TAG_CUTE_STORY":"5525",
"TAG_DANCERS":"8248",
"TAG_DAO_COMPANION":"10343",
"TAG_DAO_COMPREHENSION":"6242",
"TAG_DAOISM":"3824",
"TAG_DARK":"4599",
"TAG_DEAD_PROTAGONIST":"2215",
"TAG_DEATH":"2142",
"TAG_DEATH_OF_LOVED_ONES":"1615",
"TAG_DEBTS":"5333",
"TAG_DELINQUENTS":"749",
"TAG_DELUSIONS":"1362",
"TAG_DEMIHUMANS":"5526",
"TAG_DEMON_LORD":"2386",
"TAG_DEMONIC_CULTIVATION_TECHNIQUE":"21268",
"TAG_DEMONS":"86",
"TAG_DENSE_PROTAGONIST":"14541",
"TAG_DEPICTIONS_OF_CRUELTY":"12964",
"TAG_DEPRESSION":"1946",
"TAG_DESTINY":"3135",
"TAG_DETECTIVES":"1200",
"TAG_DETERMINED_PROTAGONIST":"12959",
"TAG_DEVOTED_LOVE_INTERESTS":"15456",
"TAG_DIFFERENT_SOCIAL_STATUS":"2243",
"TAG_DISABILITIES":"19241",
"TAG_DISCRIMINATION":"258",
"TAG_DISFIGUREMENT":"13407",
"TAG_DISHONEST_PROTAGONIST":"2343",
"TAG_DISTRUSTFUL_PROTAGONIST":"7949",
"TAG_DIVINATION":"2019",
"TAG_DIVINE_PROTECTION":"4706",
"TAG_DIVORCE":"2305",
"TAG_DOCTORS":"2876",
"TAG_DOLLSPUPPETS":"16412",
"TAG_DOMESTIC_AFFAIRS":"2663",
"TAG_DOTING_LOVE_INTERESTS":"15026",
"TAG_DOTING_OLDER_SIBLINGS":"15025",
"TAG_DOTING_PARENTS":"14674",
"TAG_DRAGON_RIDERS":"509",
"TAG_DRAGON_SLAYERS":"897",
"TAG_DRAGONS":"72",
"TAG_DREAMS":"1406",
"TAG_DRUGS":"311",
"TAG_DRUIDS":"8126",
"TAG_DUNGEON_MASTER":"174",
"TAG_DUNGEONS":"175",
"TAG_DWARFS":"3569",
"TAG_DYSTOPIA":"1283",
"TAG_ESPORTS":"15108",
"TAG_EARLY_ROMANCE":"7711",
"TAG_EARTH_INVASION":"1661",
"TAG_EASY_GOING_LIFE":"5431",
"TAG_ECONOMICS":"784",
"TAG_EDITORS":"1878",
"TAG_EIDETIC_MEMORY":"3796",
"TAG_ELDERLY_PROTAGONIST":"13177",
"TAG_ELEMENTAL_MAGIC":"9855",
"TAG_ELVES":"165",
"TAG_EMOTIONALLY_WEAK_PROTAGONIST":"13305",
"TAG_EMPIRES":"3570",
"TAG_ENEMIES_BECOME_ALLIES":"840",
"TAG_ENEMIES_BECOME_LOVERS":"113",
"TAG_ENGAGEMENT":"263",
"TAG_ENGINEER":"2735",
"TAG_ENLIGHTENMENT":"4480",
"TAG_EPISODIC":"1798",
"TAG_EUNUCH":"10593",
"TAG_EUROPEAN_AMBIENCE":"7778",
"TAG_EVIL_GODS":"10172",
"TAG_EVIL_ORGANIZATIONS":"5411",
"TAG_EVIL_PROTAGONIST":"12874",
"TAG_EVIL_RELIGIONS":"7087",
"TAG_EVOLUTION":"2049",
"TAG_EXHIBITIONISM":"6365",
"TAG_EXORCISM":"711",
"TAG_EYE_POWERS":"200",
"TAG_FAIRIES":"525",
"TAG_FALLEN_ANGELS":"134",
"TAG_FALLEN_NOBILITY":"734",
"TAG_FAMILIAL_LOVE":"12009",
"TAG_FAMILIARS":"2152",
"TAG_FAMILY":"641",
"TAG_FAMILY_BUSINESS":"2013",
"TAG_FAMILY_CONFLICT":"8664",
"TAG_FAMOUS_PARENTS":"1833",
"TAG_FAMOUS_PROTAGONIST":"14555",
"TAG_FANATICISM":"5399",
"TAG_FANFICTION":"5691",
"TAG_FANTASY_CREATURES":"771",
"TAG_FANTASY_WORLD":"99",
"TAG_FARMING":"3068",
"TAG_FAST_CULTIVATION":"5068",
"TAG_FAST_LEARNER":"7599",
"TAG_FAT_PROTAGONIST":"13721",
"TAG_FAT_TO_FIT":"15974",
"TAG_FATED_LOVERS":"2574",
"TAG_FEARLESS_PROTAGONIST":"14675",
"TAG_FELLATIO":"3953",
"TAG_FEMALE_MASTER":"5262",
"TAG_FEMALE_PROTAGONIST":"2879",
"TAG_FEMALE_TO_MALE":"4178",
"TAG_FENG_SHUI":"10919",
"TAG_FIREARMS":"9340",
"TAG_FIRST_LOVE":"1569",
"TAG_FIRSTTIME_INTERCOURSE":"4880",
"TAG_FLASHBACKS":"6061",
"TAG_FLEET_BATTLES":"17020",
"TAG_FOLKLORE":"923",
"TAG_FORCED_INTO_A_RELATIONSHIP":"1353",
"TAG_FORCED_LIVING_ARRANGEMENTS":"606",
"TAG_FORCED_MARRIAGE":"3052",
"TAG_FORGETFUL_PROTAGONIST":"2367",
"TAG_FORMER_HERO":"7405",
"TAG_FOUND_FAMILY":"47861",
"TAG_FOX_SPIRITS":"6222",
"TAG_FRIENDS_BECOME_ENEMIES":"1576",
"TAG_FRIENDSHIP":"1476",
"TAG_FUJOSHI":"797",
"TAG_FUTANARI":"3468",
"TAG_FUTURISTIC_SETTING":"2616",
"TAG_GALGE":"7643",
"TAG_GAMBLING":"9425",
"TAG_GAME_ELEMENTS":"93",
"TAG_GAME_RANKING_SYSTEM":"16272",
"TAG_GAMERS":"225",
"TAG_GANGS":"313",
"TAG_GATE_TO_ANOTHER_WORLD":"5382",
"TAG_GENDERLESS_PROTAGONIST":"9295",
"TAG_GENERALS":"13888",
"TAG_GENETIC_MODIFICATIONS":"17629",
"TAG_GENIES":"2014",
"TAG_GENIUS_PROTAGONIST":"14581",
"TAG_GHOSTS":"515",
"TAG_GLADIATORS":"2044",
"TAG_GLASSESWEARING_LOVE_INTERESTS":"15547",
"TAG_GLASSESWEARING_PROTAGONIST":"15548",
"TAG_GOBLINS":"11494",
"TAG_GOD_PROTAGONIST":"6683",
"TAG_GODHUMAN_RELATIONSHIP":"1354",
"TAG_GODDESSES":"1355",
"TAG_GODLY_POWERS":"73",
"TAG_GODS":"177",
"TAG_GOLEMS":"4437",
"TAG_GORE":"455",
"TAG_GRAVE_KEEPERS":"1736",
"TAG_GRINDING":"807",
"TAG_GUARDIAN_RELATIONSHIP":"2005",
"TAG_GUIDEVERSE":"47165",
"TAG_GUILDS":"438",
"TAG_GUNFIGHTERS":"792",
"TAG_HACKERS":"1753",
"TAG_HALFHUMAN_PROTAGONIST":"9445",
"TAG_HANDJOB":"9873",
"TAG_HANDSOME_MALE_LEAD":"192",
"TAG_HARDWORKING_PROTAGONIST":"14431",
"TAG_HAREMSEEKING_PROTAGONIST":"14992",
"TAG_HARSH_TRAINING":"8149",
"TAG_HATED_PROTAGONIST":"2307",
"TAG_HEALERS":"12141",
"TAG_HEARTWARMING":"5267",
"TAG_HEAVEN":"242",
"TAG_HEAVENLY_TRIBULATION":"4770",
"TAG_HELL":"4720",
"TAG_HELPFUL_PROTAGONIST":"15545",
"TAG_HERBALIST":"808",
"TAG_HEROES":"100",
"TAG_HETEROCHROMIA":"2111",
"TAG_HIDDEN_ABILITIES":"7227",
"TAG_HIDING_TRUE_ABILITIES":"6384",
"TAG_HIDING_TRUE_IDENTITY":"10134",
"TAG_HIKIKOMORI":"765",
"TAG_HOMUNCULUS":"2741",
"TAG_HONEST_PROTAGONIST":"1772",
"TAG_HOSPITAL":"1387",
"TAG_HOTBLOODED_PROTAGONIST":"13502",
"TAG_HUMAN_EXPERIMENTATION":"12338",
"TAG_HUMAN_WEAPON":"1687",
"TAG_HUMANNONHUMAN_RELATIONSHIP":"259",
"TAG_HUMANOID_PROTAGONIST":"17218",
"TAG_HUNTERS":"494",
"TAG_HYPNOTISM":"1711",
"TAG_IDENTITY_CRISIS":"10075",
"TAG_IMAGINARY_FRIEND":"3555",
"TAG_IMMORTALS":"233",
"TAG_IMPERIAL_HAREM":"9033",
"TAG_INCEST":"626",
"TAG_INCUBUS":"3398",
"TAG_INDECISIVE_PROTAGONIST":"2319",
"TAG_INDUSTRIALIZATION":"12135",
"TAG_INFERIORITY_COMPLEX":"506",
"TAG_INHERITANCE":"1400",
"TAG_INSCRIPTIONS":"5132",
"TAG_INSECTS":"550",
"TAG_INTERCONNECTED_STORYLINES":"4539",
"TAG_INTERDIMENSIONAL_TRAVEL":"11229",
"TAG_INTROVERTED_PROTAGONIST":"14993",
"TAG_INVESTIGATIONS":"9064",
"TAG_INVISIBILITY":"3978",
"TAG_JACK_OF_ALL_TRADES":"3687",
"TAG_JEALOUSY":"1864",
"TAG_JIANGSHI":"6665",
"TAG_JOBLESS_CLASS":"7086",
"TAG_JSDF":"5300",
"TAG_KIDNAPPINGS":"1250",
"TAG_KIND_LOVE_INTERESTS":"13901",
"TAG_KINGDOM_BUILDING":"3869",
"TAG_KINGDOMS":"1904",
"TAG_KNIGHTS":"137",
"TAG_KUUDERE":"571",
"TAG_LACK_OF_COMMON_SENSE":"5086",
"TAG_LANGUAGE_BARRIER":"5426",
"TAG_LATE_ROMANCE":"5920",
"TAG_LAWYERS":"4551",
"TAG_LAZY_PROTAGONIST":"338",
"TAG_LEADERSHIP":"6706",
"TAG_LEGENDS":"3430",
"TAG_LEVEL_SYSTEM":"7443",
"TAG_LIBRARY":"1402",
"TAG_LIFE_EXTENSION_SYSTEM":"84407",
"TAG_LIMITED_LIFESPAN":"2222",
"TAG_LIVESTREAMING":"49529",
"TAG_LIVING_ABROAD":"3154",
"TAG_LIVING_ALONE":"1437",
"TAG_LOLI":"3715",
"TAG_LONELINESS":"865",
"TAG_LONER_PROTAGONIST":"651",
"TAG_LONG_SEPARATIONS":"2891",
"TAG_LONGDISTANCE_RELATIONSHIP":"1859",
"TAG_LOST_CIVILIZATIONS":"1696",
"TAG_LOTTERY":"7151",
"TAG_LOVE_AT_FIRST_SIGHT":"1561",
"TAG_LOVE_INTEREST_FALLS_IN_LOVE_FIRST":"19605",
"TAG_LOVE_RIVALS":"627",
"TAG_LOVE_TRIANGLES":"607",
"TAG_LOVERS_REUNITED":"1616",
"TAG_LOWKEY_PROTAGONIST":"9161",
"TAG_LOYAL_SUBORDINATES":"12035",
"TAG_LUCKY_PROTAGONIST":"6526",
"TAG_MAGIC":"60",
"TAG_MAGIC_BEASTS":"6095",
"TAG_MAGIC_FORMATIONS":"3038",
"TAG_MAGICAL_GIRLS":"516",
"TAG_MAGICAL_SPACE":"3460",
"TAG_MAGICAL_TECHNOLOGY":"14900",
"TAG_MAIDS":"336",
"TAG_MALE_PROTAGONIST":"3257",
"TAG_MALE_TO_FEMALE":"171",
"TAG_MALE_YANDERE":"557",
"TAG_MANAGEMENT":"2604",
"TAG_MANGAKA":"2781",
"TAG_MANIPULATIVE_CHARACTERS":"12963",
"TAG_MANLY_GAY_COUPLE":"2084",
"TAG_MARRIAGE":"642",
"TAG_MARRIAGE_OF_CONVENIENCE":"706",
"TAG_MARTIAL_SPIRITS":"10145",
"TAG_MASOCHISTIC_CHARACTERS":"19604",
"TAG_MASTERDISCIPLE_RELATIONSHIP":"667",
"TAG_MASTERSERVANT_RELATIONSHIP":"260",
"TAG_MASTURBATION":"2501",
"TAG_MATRIARCHY":"6437",
"TAG_MATURE_PROTAGONIST":"279",
"TAG_MEDICAL_KNOWLEDGE":"9021",
"TAG_MEDIEVAL":"4498",
"TAG_MERCENARIES":"9573",
"TAG_MERCHANTS":"14516",
"TAG_MILITARY":"589",
"TAG_MIND_BREAK":"6073",
"TAG_MIND_CONTROL":"456",
"TAG_MISANDRY":"11503",
"TAG_MISMATCHED_COUPLE":"1516",
"TAG_MISTAKEN_IDENTITY":"50416",
"TAG_MISUNDERSTANDINGS":"172",
"TAG_MMORPG":"105",
"TAG_MOB_PROTAGONIST":"12487",
"TAG_MODELS":"14781",
"TAG_MODERN_DAY":"2606",
"TAG_MODERN_KNOWLEDGE":"2666",
"TAG_MONEY_GRUBBER":"3754",
"TAG_MONSTER_GIRLS":"510",
"TAG_MONSTER_SOCIETY":"8988",
"TAG_MONSTER_TAMER":"253",
"TAG_MONSTERS":"261",
"TAG_MOVIES":"345",
"TAG_MPREG":"20139",
"TAG_MULTIPLE_IDENTITIES":"7163",
"TAG_MULTIPLE_PERSONALITIES":"8266",
"TAG_MULTIPLE_POV":"14639",
"TAG_MULTIPLE_PROTAGONISTS":"441",
"TAG_MULTIPLE_REALMS":"3706",
"TAG_MULTIPLE_REINCARNATED_INDIVIDUALS":"5149",
"TAG_MULTIPLE_TIMELINES":"7802",
"TAG_MULTIPLE_TRANSPORTED_INDIVIDUALS":"16138",
"TAG_MURDERS":"885",
"TAG_MUSIC":"1231",
"TAG_MUTATED_CREATURES":"5036",
"TAG_MUTATIONS":"68",
"TAG_MUTE_CHARACTER":"1141",
"TAG_MYSTERIOUS_FAMILY_BACKGROUND":"8440",
"TAG_MYSTERIOUS_ILLNESS":"2224",
"TAG_MYSTERIOUS_PAST":"4783",
"TAG_MYSTERY_SOLVING":"3537",
"TAG_MYTHICAL_BEASTS":"8995",
"TAG_MYTHOLOGY":"1474",
"TAG_NAIVE_PROTAGONIST":"14644",
"TAG_NARCISSISTIC_PROTAGONIST":"14994",
"TAG_NATIONALISM":"6204",
"TAG_NEARDEATH_EXPERIENCE":"130",
"TAG_NECROMANCER":"186",
"TAG_NEET":"1728",
"TAG_NETORARE":"4126",
"TAG_NETORASE":"11561",
"TAG_NETORI":"3862",
"TAG_NIGHTMARES":"6164",
"TAG_NINJAS":"1725",
"TAG_NOBLES":"265",
"TAG_NONHUMANOID_PROTAGONIST":"17199",
"TAG_NONLINEAR_STORYTELLING":"2514",
"TAG_NUDITY":"1524",
"TAG_NURSES":"7551",
"TAG_OBSESSIVE_LOVE":"1477",
"TAG_OFFICE_ROMANCE":"9331",
"TAG_OLDER_LOVE_INTERESTS":"16202",
"TAG_OMEGAVERSE":"14574",
"TAG_ONESHOT":"10980",
"TAG_ONLINE_ROMANCE":"5122",
"TAG_ONMYOUJI":"2060",
"TAG_ORCS":"6211",
"TAG_ORGANIZED_CRIME":"2645",
"TAG_ORGY":"11994",
"TAG_ORPHANS":"125",
"TAG_OTAKU":"277",
"TAG_OTOME_GAME":"466",
"TAG_OUTCASTS":"726",
"TAG_OUTDOOR_INTERCOURSE":"1222",
"TAG_OUTER_SPACE":"875",
"TAG_OVERPOWERED_PROTAGONIST":"4598",
"TAG_OVERPROTECTIVE_SIBLINGS":"145",
"TAG_PACIFIST_PROTAGONIST":"8832",
"TAG_PAIZURI":"6049",
"TAG_PARALLEL_WORLDS":"318",
"TAG_PARASITES":"1300",
"TAG_PARENT_COMPLEX":"4741",
"TAG_PARODY":"2350",
"TAG_PARTTIME_JOB":"628",
"TAG_PAST_PLAYS_A_BIG_ROLE":"220",
"TAG_PAST_TRAUMA":"6457",
"TAG_PERSISTENT_LOVE_INTERESTS":"15546",
"TAG_PERSONALITY_CHANGES":"488",
"TAG_PERVERTED_PROTAGONIST":"14643",
"TAG_PETS":"2710",
"TAG_PHARMACIST":"5623",
"TAG_PHILOSOPHICAL":"1799",
"TAG_PHOBIAS":"1817",
"TAG_PHOENIXES":"8790",
"TAG_PHOTOGRAPHY":"1371",
"TAG_PILL_BASED_CULTIVATION":"3019",
"TAG_PILL_CONCOCTING":"9071",
"TAG_PILOTS":"1215",
"TAG_PIRATES":"3025",
"TAG_PLAYBOYS":"1311",
"TAG_PLAYFUL_PROTAGONIST":"13369",
"TAG_POETRY":"7813",
"TAG_POISONS":"2674",
"TAG_POLICE":"83",
"TAG_POLITE_PROTAGONIST":"14996",
"TAG_POLITICS":"298",
"TAG_POLYANDRY":"11890",
"TAG_POLYGAMY":"2684",
"TAG_POOR_PROTAGONIST":"12909",
"TAG_POOR_TO_RICH":"8801",
"TAG_POPULAR_LOVE_INTERESTS":"13481",
"TAG_POSSESSION":"94",
"TAG_POSSESSIVE_CHARACTERS":"12966",
"TAG_POSTAPOCALYPTIC":"1301",
"TAG_POWER_COUPLE":"2551",
"TAG_POWER_STRUGGLE":"673",
"TAG_PRAGMATIC_PROTAGONIST":"564",
"TAG_PRECOGNITION":"2020",
"TAG_PREGNANCY":"3330",
"TAG_PRETEND_LOVERS":"1763",
"TAG_PREVIOUS_LIFE_TALENT":"1124",
"TAG_PRIESTESSES":"3534",
"TAG_PRIESTS":"2341",
"TAG_PRISON":"1426",
"TAG_PROACTIVE_PROTAGONIST":"701",
"TAG_PROGRAMMER":"6302",
"TAG_PROPHECIES":"13215",
"TAG_PROSTITUTES":"1892",
"TAG_PROTAGONIST_FALLS_IN_LOVE_FIRST":"19606",
"TAG_PROTAGONIST_STRONG_FROM_THE_START":"167",
"TAG_PROTAGONIST_WITH_MULTIPLE_BODIES":"18652",
"TAG_PSYCHIC_POWERS":"13480",
"TAG_PSYCHOPATHS":"846",
"TAG_PUPPETEERS":"9950",
"TAG_QUIET_CHARACTERS":"13370",
"TAG_QUIRKY_CHARACTERS":"931",
"TAG_R15":"2738",
"TAG_R18":"4074",
"TAG_RACE_CHANGE":"2903",
"TAG_RACISM":"3314",
"TAG_RAPE":"431",
"TAG_RAPE_VICTIM_BECOMES_LOVER":"11714",
"TAG_REBELLION":"5574",
"TAG_REINCARNATED_AS_A_MONSTER":"447",
"TAG_REINCARNATED_AS_AN_OBJECT":"9480",
"TAG_REINCARNATED_IN_A_GAME_WORLD":"7297",
"TAG_REINCARNATED_IN_ANOTHER_WORLD":"6304",
"TAG_REINCARNATION":"120",
"TAG_RELIGIONS":"15178",
"TAG_RELUCTANT_PROTAGONIST":"179",
"TAG_REPORTERS":"1684",
"TAG_RESTAURANT":"1835",
"TAG_RESURRECTION":"1209",
"TAG_RETURNING_FROM_ANOTHER_WORLD":"13303",
"TAG_REVENGE":"121",
"TAG_REVERSE_HAREM":"558",
"TAG_REVERSE_RAPE":"4500",
"TAG_REVERSIBLE_COUPLE":"28883",
"TAG_RICH_TO_POOR":"11448",
"TAG_RIGHTEOUS_PROTAGONIST":"7780",
"TAG_RIVALRY":"614",
"TAG_ROMANTIC_SUBPLOT":"334",
"TAG_ROOMMATES":"106",
"TAG_ROYALTY":"335",
"TAG_RUTHLESS_PROTAGONIST":"12916",
"TAG_SADISTIC_CHARACTERS":"13496",
"TAG_SAINTS":"7288",
"TAG_SALARYMAN":"1189",
"TAG_SAMURAI":"826",
"TAG_SAVING_THE_WORLD":"788",
"TAG_SCHEMES_AND_CONSPIRACIES":"24959",
"TAG_SCHIZOPHRENIA":"2288",
"TAG_SCIENTISTS":"843",
"TAG_SCULPTORS":"426",
"TAG_SEALED_POWER":"732",
"TAG_SECOND_CHANCE":"2571",
"TAG_SECRET_CRUSH":"1475",
"TAG_SECRET_IDENTITY":"214",
"TAG_SECRET_ORGANIZATIONS":"827",
"TAG_SECRET_RELATIONSHIP":"1190",
"TAG_SECRETIVE_PROTAGONIST":"14997",
"TAG_SECRETS":"1623",
"TAG_SECT_DEVELOPMENT":"7536",
"TAG_SEDUCTION":"2595",
"TAG_SEEING_THINGS_OTHER_HUMANS_CANT":"201",
"TAG_SELFISH_PROTAGONIST":"1463",
"TAG_SELFLESS_PROTAGONIST":"1372",
"TAG_SEME_PROTAGONIST":"14319",
"TAG_SENPAIKOUHAI_RELATIONSHIP":"629",
"TAG_SENTIENT_OBJECTS":"13520",
"TAG_SENTIMENTAL_PROTAGONIST":"13498",
"TAG_SERIAL_KILLERS":"1328",
"TAG_SERVANTS":"254",
"TAG_SEVEN_DEADLY_SINS":"3863",
"TAG_SEVEN_VIRTUES":"13993",
"TAG_SEX_FRIENDS":"4432",
"TAG_SEX_SLAVES":"656",
"TAG_SEXUAL_ABUSE":"3252",
"TAG_SEXUAL_CULTIVATION_TECHNIQUE":"6245",
"TAG_SHAMELESS_PROTAGONIST":"13802",
"TAG_SHAPESHIFTERS":"10602",
"TAG_SHARING_A_BODY":"7874",
"TAG_SHARPTONGUED_CHARACTERS":"13996",
"TAG_SHIELD_USER":"17746",
"TAG_SHIKIGAMI":"2280",
"TAG_SHORT_STORY":"3358",
"TAG_SHOTA":"5580",
"TAG_SHOUJOAI_SUBPLOT":"7147",
"TAG_SHOUNENAI_SUBPLOT":"7146",
"TAG_SHOWBIZ":"565",
"TAG_SHY_CHARACTERS":"13499",
"TAG_SIBLING_RIVALRY":"1971",
"TAG_SIBLINGS_CARE":"8186",
"TAG_SIBLINGS":"1411",
"TAG_SIBLINGS_NOT_RELATED_BY_BLOOD":"65",
"TAG_SICKLY_CHARACTERS":"13199",
"TAG_SIGN_LANGUAGE":"8631",
"TAG_SINGERS":"209",
"TAG_SINGLE_PARENT":"1985",
"TAG_SISTER_COMPLEX":"668",
"TAG_SKILL_ASSIMILATION":"3820",
"TAG_SKILL_BOOKS":"7032",
"TAG_SKILL_CREATION":"6753",
"TAG_SLAVE_HAREM":"3936",
"TAG_SLAVE_PROTAGONIST":"5420",
"TAG_SLAVES":"180",
"TAG_SLEEPING":"3014",
"TAG_SLOW_GROWTH_AT_START":"3185",
"TAG_SLOW_ROMANCE":"76",
"TAG_SMART_COUPLE":"831",
"TAG_SOCIAL_OUTCASTS":"652",
"TAG_SOLDIERS":"674",
"TAG_SOUL_POWER":"7828",
"TAG_SOULS":"4627",
"TAG_SPATIAL_MANIPULATION":"8777",
"TAG_SPEAR_WIELDER":"4842",
"TAG_SPECIAL_ABILITIES":"323",
"TAG_SPIES":"2069",
"TAG_SPIRIT_ADVISOR":"2586",
"TAG_SPIRIT_USERS":"11422",
"TAG_SPIRITS":"202",
"TAG_STALKERS":"1713",
"TAG_STOCKHOLM_SYNDROME":"1373",
"TAG_STOIC_CHARACTERS":"13500",
"TAG_STORE_OWNER":"13633",
"TAG_STRAIGHT_SEME":"1191",
"TAG_STRAIGHT_UKE":"1594",
"TAG_STRATEGIC_BATTLES":"675",
"TAG_STRATEGIST":"4777",
"TAG_STRENGTHBASED_SOCIAL_HIERARCHY":"14788",
"TAG_STRONG_LOVE_INTERESTS":"12881",
"TAG_STRONG_TO_STRONGER":"4971",
"TAG_STUBBORN_PROTAGONIST":"1643",
"TAG_STUDENT_COUNCIL":"608",
"TAG_STUDENTTEACHER_RELATIONSHIP":"1224",
"TAG_SUCCUBUS":"645",
"TAG_SUDDEN_STRENGTH_GAIN":"898",
"TAG_SUDDEN_WEALTH":"9574",
"TAG_SUICIDES":"1743",
"TAG_SUMMONED_HERO":"2990",
"TAG_SUMMONING_MAGIC":"4127",
"TAG_SURVIVAL":"347",
"TAG_SURVIVAL_GAME":"348",
"TAG_SWORD_AND_MAGIC":"4302",
"TAG_SWORD_WIELDER":"18792",
"TAG_SYSTEM_ADMINISTRATOR":"7357",
"TAG_TEACHERS":"1749",
"TAG_TEAMWORK":"1847",
"TAG_TECHNOLOGICAL_GAP":"16962",
"TAG_TENTACLES":"8760",
"TAG_TERMINAL_ILLNESS":"2225",
"TAG_TERRORISTS":"2196",
"TAG_THIEVES":"1360",
"TAG_THREESOME":"1420",
"TAG_THRILLER":"2970",
"TAG_TIME_LOOP":"886",
"TAG_TIME_MANIPULATION":"2054",
"TAG_TIME_PARADOX":"887",
"TAG_TIME_SKIP":"360",
"TAG_TIME_TRAVEL":"92",
"TAG_TIMID_PROTAGONIST":"5085",
"TAG_TOMBOYISH_FEMALE_LEAD":"267",
"TAG_TORTURE":"355",
"TAG_TOYS":"14264",
"TAG_TRAGIC_PAST":"148",
"TAG_TRANSFORMATION_ABILITY":"16178",
"TAG_TRANSMIGRATION":"3046",
"TAG_TRANSPLANTED_MEMORIES":"4323",
"TAG_TRANSPORTED_INTO_A_GAME_WORLD":"7663",
"TAG_TRANSPORTED_MODERN_STRUCTURE":"6559",
"TAG_TRANSPORTED_TO_ANOTHER_WORLD":"15008",
"TAG_TRAP":"1279",
"TAG_TRIBAL_SOCIETY":"5825",
"TAG_TRICKSTER":"4856",
"TAG_TSUNDERE":"795",
"TAG_TWINS":"518",
"TAG_TWISTED_PERSONALITY":"10488",
"TAG_UGLY_PROTAGONIST":"12155",
"TAG_UGLY_TO_BEAUTIFUL":"4851",
"TAG_UNCONDITIONAL_LOVE":"1595",
"TAG_UNDERESTIMATED_PROTAGONIST":"12907",
"TAG_UNIQUE_CULTIVATION_TECHNIQUE":"3718",
"TAG_UNIQUE_WEAPON_USER":"13875",
"TAG_UNIQUE_WEAPONS":"13874",
"TAG_UNLIMITED_FLOW":"38534",
"TAG_UNLUCKY_PROTAGONIST":"2314",
"TAG_UNRELIABLE_NARRATOR":"4697",
"TAG_UNREQUITED_LOVE":"1268",
"TAG_VALKYRIES":"17588",
"TAG_VAMPIRES":"149",
"TAG_VILLAINESS_NOBLE_GIRLS":"11404",
"TAG_VIRTUAL_REALITY":"109",
"TAG_VOCALOID":"1634",
"TAG_VOICE_ACTORS":"2887",
"TAG_VOYEURISM":"3256",
"TAG_WAITERS":"1216",
"TAG_WAR_RECORDS":"5128",
"TAG_WARS":"101",
"TAG_WEAK_PROTAGONIST":"12813",
"TAG_WEAK_TO_STRONG":"71",
"TAG_WEALTHY_CHARACTERS":"13334",
"TAG_WEREBEASTS":"17533",
"TAG_WISHES":"1338",
"TAG_WITCHES":"1829",
"TAG_WIZARDS":"634",
"TAG_WORLD_HOPPING":"21767",
"TAG_WORLD_TRAVEL":"364",
"TAG_WORLD_TREE":"13198",
"TAG_WRITERS":"548",
"TAG_YANDERE":"291",
"TAG_YOUKAI":"926",
"TAG_YOUNGER_BROTHERS":"11677",
"TAG_YOUNGER_LOVE_INTERESTS":"16201",
"TAG_YOUNGER_SISTERS":"11678",
"TAG_ZOMBIES":"350",
}