# Novel Types
NOVEL_TYPES={
"NT_LIGHTNOVEL_NUM":"2443",
"NT_PUBLISHEDNOVEL_NUM":"26874",
"NT_WEBNOVEL_NUM":"2444",
}

# Language
LANGUAGE={
"LANG_CHINESE":"495",
"LANG_FILIPINO":"9181",
"LANG_INDONESIAN":"9179",
"LANG_JAPANESE":"496",
"LANG_KHMER":"18657",
"LANG_KOREAN":"497",
"LANG_MALAYSIAN":"9183",
"LANG_THAI":"9954",
"LANG_VIETNAMESE":"9177",
}

# Search Types
AND_SEARCH="and"
OR_SEARCH='or'
MIN_SEARCH="min"
MAX_SEARCH="max"
INCLUDE_SEARCH="1"
EXCLUDE_SEARCH="2"

# Story Status
STORY_STATUS={
"SS_COMPLETED":"2",
"SS_ONGOING":"3",
"SS_HIATUS":"4",
}

# Sort By
SORT_CHAPTER="srel"
SORT_FREQUENCY="sfrel"
SORT_RATING="srate"
SORT_READER="sread"
SORT_REVIEWS="sreview"
SORT_TITLE="abc"
SORT_LAST_UPDATED="sdate"

# Sort Type
SORT_ASCENDING='asc'
SORT_DESCENDING="desc"